==> PPDF_1_2.zip: PubMedPDF/favorite.php <==
<?php
	include "header.php";
	include "style.php";
	include "include/favorite_functions.php";

	($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";
	
	# data all check script
	echo <<<E
	<script>
	var c=true;
	function check(){
		for(i=0; i<(document.datalist.elements.length); i++){
				document.datalist.elements[i].checked = c;
		}
		if(c == true){
			c=false;
		}else{
			c=true;
		}
	}
	</script>
E;
	
	# delete directory
	if(@$_GET["deld_id"]){
		$deld = array();
		$deld[] = intval(@$_GET["deld_id"]);
		$sql = "SELECT * FROM ".$T_FDIR." WHERE Pass like '%[".$deld[0]."]%'";
		$res = mysql_query($sql, $conn);
		while($row = mysql_fetch_array($res,MYSQL_ASSOC)){
			$deld[] = $row["id"];
		}
		
		for($i=0; $i<count($deld); $i++){
			$sql = "UPDATE ".$T_FDATA." SET dir_id='0' WHERE dir_id='".$deld[$i]."'";
			$res = mysql_query($sql, $conn);
		}
		
		for($i=0; $i<count($deld); $i++){
			$sql = "DELETE FROM ".$T_FDIR." WHERE id='".$deld[$i]."'";
			$res = mysql_query($sql, $conn);
		}		
	}

	# dir id & pass
	if(@$_GET["d_id"]){
		$dir_id = intval(@$_GET["d_id"]);
		$sql = "SELECT * FROM ".$T_FDIR." WHERE id='".$dir_id."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$pass = $row["Pass"]."[".@$_GET["d_id"]."]";

	}else{
		$dir_id=0;
		$pass="";
	}
	
	if(@$_GET["ptop"]){
		$dir_id=0;
		$pass="";
	}

	# mkdir
	echo "<div class=\"pt\">"._MD_FAVORITE_MKDIR."</div>";
	echo "<form actin=\"".$_SERVER[PHP_SELF]."\" method=\"GET\">";
	echo "<input type=\"text\" size=\"24\" name=\"mkdir_name\">";
	echo "<input type=\"hidden\" name=\"pass\" value=\"".$pass."\">";
	echo "<input type=\"submit\" name=\"mkdir\" value=\"submit\">";
	echo "</form>";

	if(@$_GET["mkdir"]){
		$dir = trim(@$_GET["mkdir_name"]);
		$pass = "";
		if($pass = @$_GET["pass"]);
		$sql = "INSERT INTO ".$T_FDIR." VALUES('','".$user."','".$dir."','".$pass."','')";
		$res = mysql_query($sql, $conn);
	}

	# move data	
	if(@$_GET["mv_data"]){	
		$method = @$_GET["mv_method"];

		if($method == "insert"){
			foreach(@$_GET["data"] as $key => $value){
				$sql = "UPDATE ".$T_FDATA." SET dir_id='".@$_GET["dir"]."' WHERE id='".$value."'";
				$res = mysql_query($sql, $conn);
			}
			
		}elseif($method == "delete"){
			foreach(@$_GET["data"] as $key => $value){
				$sql = "DELETE FROM ".$T_FDATA." WHERE id='".$value."'";
				$res = mysql_query($sql, $conn);
			}
			
		}elseif($method == "biblio"){
			#xoops_pmid_tmp (biblio, user, dataid, )
			foreach(@$_GET["data"] as $key => $value){
				$sql = "SELECT * FROM ".$T_FDATA." WHERE id='".$value."'";
				$res = mysql_query($sql, $conn);
				if(mysql_num_rows($res) > 0){
					$row = mysql_fetch_array($res, MYSQL_ASSOC);
					$dataid = $row["data_id"];
					$sql = "SELECT * FROM ".$T_TMP." WHERE tmp1='biblio' AND tmp2='".$user."' AND tmp3='".$dataid."'";
					$res = mysql_query($sql, $conn);
					if(mysql_num_rows($res) <= 0){
						$sql = "INSERT INTO ".$T_TMP." VALUES('biblio','".$user."','".$dataid."','')";
						$res = mysql_query($sql, $conn);
					}
				}
			}
		}
	}
	
	# Show data
	GET_BIBLIO_NUM($user);
	GET_FDIR($user,$dir_id);
	GET_FDATA($user, $dir_id);
	
	include (XOOPS_ROOT_PATH."/footer.php");
?>

==> PPDF_1_3.zip: PubMedPDF/favorite.php <==
<?php
	include "header.php";
	include "style.php";
	include "include/favorite_functions.php";

	($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";
	
	# data all check script
	echo <<<E
	<script>
	var c=true;
	function check(){
		for(i=0; i<(document.datalist.elements.length); i++){
				document.datalist.elements[i].checked = c;
		}
		if(c == true){
			c=false;
		}else{
			c=true;
		}
	}
	</script>
E;
	
	# delete directory
	if(@$_GET["deld_id"]){
		$deld = array();
		$deld[] = intval(@$_GET["deld_id"]);
		$sql = "SELECT * FROM ".$T_FDIR." WHERE Pass like '%[".$deld[0]."]%'";
		$res = mysql_query($sql, $conn);
		while($row = mysql_fetch_array($res,MYSQL_ASSOC)){
			$deld[] = $row["id"];
		}
		
		for($i=0; $i<count($deld); $i++){
			$sql = "UPDATE ".$T_FDATA." SET dir_id='0' WHERE dir_id='".$deld[$i]."'";
			$res = mysql_query($sql, $conn);
		}
		
		for($i=0; $i<count($deld); $i++){
			$sql = "DELETE FROM ".$T_FDIR." WHERE id='".$deld[$i]."'";
			$res = mysql_query($sql, $conn);
		}		
	}

	# dir id & pass
	if(@$_GET["d_id"]){
		$dir_id = intval(@$_GET["d_id"]);
		$sql = "SELECT * FROM ".$T_FDIR." WHERE id='".$dir_id."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$pass = $row["Pass"]."[".@$_GET["d_id"]."]";

	}else{
		$dir_id=0;
		$pass="";
	}
	
	if(@$_GET["ptop"]){
		$dir_id=0;
		$pass="";
	}

	# mkdir
	echo "<div class=\"pt\">"._MD_FAVORITE_MKDIR."</div>";
	echo "<form actin=\"".$_SERVER[PHP_SELF]."\" method=\"GET\">";
	echo "<input type=\"text\" size=\"24\" name=\"mkdir_name\">";
	echo "<input type=\"hidden\" name=\"pass\" value=\"".$pass."\">";
	echo "<input type=\"submit\" name=\"mkdir\" value=\"submit\">";
	echo "</form>";

	if(@$_GET["mkdir"]){
		$dir = trim(@$_GET["mkdir_name"]);
		$pass = "";
		if($pass = @$_GET["pass"]);
		$sql = "INSERT INTO ".$T_FDIR." VALUES('','".$user."','".$dir."','".$pass."','')";
		$res = mysql_query($sql, $conn);
	}

	# move data	
	if(@$_GET["mv_data"]){	
		$method = @$_GET["mv_method"];

		if($method == "insert"){
			foreach(@$_GET["data"] as $key => $value){
				$sql = "UPDATE ".$T_FDATA." SET dir_id='".@$_GET["dir"]."' WHERE id='".$value."'";
				$res = mysql_query($sql, $conn);
			}
			
		}elseif($method == "delete"){
			foreach(@$_GET["data"] as $key => $value){
				$sql = "SELECT data_id FROM ".$T_FDATA." WHERE id='".$value."'";
				$res = mysql_query($sql, $conn);
				$row = mysql_fetch_array($res, MYSQL_ASSOC);
				$data_id = $row["data_id"];
			
				$sql = "DELETE FROM ".$T_FDATA." WHERE id='".$value."'";
				$res = mysql_query($sql, $conn);
				
				# favorite counter
				$sql = "SELECT F_num FROM ".$T_ID." WHERE id='".$data_id."'";
				$res = mysql_query($sql, $conn);
				$row = mysql_fetch_array($res, MYSQL_ASSOC);
				$n = $row["F_num"] - 1;
				$sql = "UPDATE ".$T_ID." SET F_num='".$n."' WHERE id='".$data_id."'";
				$res = mysql_query($sql, $conn);
			}
			
		}elseif($method == "biblio"){
			#xoops_pmid_tmp (biblio, user, dataid, )
			foreach(@$_GET["data"] as $key => $value){
				$sql = "SELECT * FROM ".$T_FDATA." WHERE id='".$value."'";
				$res = mysql_query($sql, $conn);
				if(mysql_num_rows($res) > 0){
					$row = mysql_fetch_array($res, MYSQL_ASSOC);
					$dataid = $row["data_id"];
					$sql = "SELECT * FROM ".$T_TMP." WHERE tmp1='biblio' AND tmp2='".$user."' AND tmp3='".$dataid."'";
					$res = mysql_query($sql, $conn);
					if(mysql_num_rows($res) <= 0){
						$sql = "INSERT INTO ".$T_TMP." VALUES('biblio','".$user."','".$dataid."','')";
						$res = mysql_query($sql, $conn);
					}
				}
			}
		}
	}
	
	# Show data
	GET_FDIR($user,$dir_id);
	GET_FDATA($user, $dir_id);
	
	include (XOOPS_ROOT_PATH."/footer.php");
?>
